/*
 * Copyright (C) 2009-2012 Geometer Plus <contact@geometerplus.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

#include <ZLNetworkRequest.h>

#include "NetworkLink.h"
#include "NetworkOperationData.h"

NetworkOperationData::NetworkOperationData(const NetworkLink &link) : Link(link) {
}

void NetworkOperationData::clear() {
	Items.clear();
	ResumeURI.clear();
}

shared_ptr<ZLNetworkRequest> NetworkOperationData::resume() {
	shared_ptr<ZLNetworkRequest> request = Link.resume(*this);
	clear();
	return request;
}
